<?php
/**
 * Fresh Framework (Ark Theme) Integration
 * 
 * @package Page_Generator_Pro
 * @author  Tim Carr
 * @version 3.3.7
 */
class Page_Generator_Pro_Fresh_Framework extends Page_Generator_Pro_Integration {

    /**
     * Holds the base object.
     *
     * @since   3.3.7
     *
     * @var     object
     */
    public $base;

    /**
     * Constructor
     * 
     * @since   3.3.7
     *
     * @param   object  $base    Base Plugin Class
     */
    public function __construct( $base ) {

        // Store base class
        $this->base = $base;

        // Set Theme
        $this->theme_name = 'Ark';

        // Set Meta Keys used by this Plugin
        $this->meta_keys = array(
            'ff_builder_status',
            'ff-layout-settings',
        );

        // Remove Page Builder data from Group Settings if overwriting content is disabled, and an existing generated page already exists
        add_filter( 'page_generator_pro_generate_remove_content_from_settings_ignored_keys', array( $this, 'remove_post_meta_from_content_group' ), 10, 2 );

        // Remove Plugin data from Group Settings if Plugin isn't active on Generation
        add_filter( 'page_generator_pro_groups_get_settings_remove_orphaned_settings', array( $this, 'remove_orphaned_settings' ) );

    }

    /**
     * Removes orphaned Fresh Framework metadata in the Group Settings during Generation,
     * if Fresh Framework is not active
     * 
     * @since   3.3.7
     * 
     * @param   array   $settings   Group Settings
     * @return  array               Group Settings
     */
    public function remove_orphaned_settings( $settings ) {

        // Don't remove settings if the Plugin is active
        if ( $this->is_theme_active() ) {
            return $settings;
        }

        // Remove Fresh Framework Meta Keys from the Group Settings during Generation
        return $this->remove_orphaned_settings_metadata( $settings, $this->meta_keys );

    }

}