<?php
/**
 * Infinite Theme integration
 * 
 * @package Page_Generator_Pro
 * @author  Tim Carr
 * @version 3.0.7
 */
class Page_Generator_Pro_Goodlayers_Infinite extends Page_Generator_Pro_Integration {

    /**
     * Holds the base object.
     *
     * @since   3.3.9
     *
     * @var     object
     */
    public $base;

    /**
     * Constructor
     * 
     * @since   3.3.9
     *
     * @param   object  $base    Base Plugin Class
     */
    public function __construct( $base ) {

        // Store base class
        $this->base = $base;

        // Set Plugin
        $this->plugin_folder_filename = 'goodlayers-core/goodlayers-core.php';

        // Set Theme Name
        $this->theme_name = 'Infinite';

        // Register Infinite Theme Page Options
        add_action( 'init', array( $this, 'register_support' ) );
        
    }

    /**
     * Registers Infinite Theme's Page and Post Options on Page Generator Pro's Groups
     *
     * @since   3.3.9
     */
    public function register_support() {

        // Bail if GoodLayers isn't active
    	if ( ! $this->is_active() ) {
    		return;
    	}

        // Bail if Infinite Theme isn't active
        if ( ! $this->is_theme_active() ) {
            return;
        }
        
        // Register Page Options
        new gdlr_core_page_option(array(
            'post_type' => array( $this->base->plugin->name ),
            'options' => array(
                'layout' => array(
                    'title' => esc_html__('Layout', 'infinite'),
                    'options' => array(
                        'custom-header' => array(
                            'title' => esc_html__('Select Custom Header', 'infinite'),
                            'type' => 'combobox',
                            'single' => 'gdlr_core_custom_header_id',
                            'options' => array('' => esc_html__('Default', 'infinite')) + gdlr_core_get_post_list('gdlr_core_header')
                        ),
                        'enable-header-area' => array(
                            'title' => esc_html__('Enable Header Area', 'infinite'),
                            'type' => 'checkbox',
                            'default' => 'enable'
                        ),
                        'enable-logo' => array(
                            'title' => esc_html__('Enable Logo', 'infinite'),
                            'type' => 'combobox',
                            'options' => array(
                                '' => esc_html__('Default', 'infinite'),
                                'enable' => esc_html__('Enable', 'infinite'),
                                'disable' => esc_html__('Disable', 'infinite')
                            ),
                            'single' => 'gdlr-enable-logo',
                            'condition' => array( 'enable-header-area' => 'enable' )
                        ),
                        'sticky-navigation' => array(
                            'title' => esc_html__('Sticky Navigation', 'infinite'),
                            'type' => 'combobox',
                            'options' => array(
                                'default' => esc_html__('Default', 'infinite'),
                                'enable' => esc_html__('Enable', 'infinite'),
                                'disable' => esc_html__('Disable', 'infinite'),
                            ),
                            'condition' => array( 'enable-header-area' => 'enable' )
                        ),
                        'enable-page-title' => array(
                            'title' => esc_html__('Enable Page Title', 'infinite'),
                            'type' => 'checkbox',
                            'default' => 'enable',
                            'condition' => array( 'enable-header-area' => 'enable' )
                        ),
                        'page-caption' => array(
                            'title' => esc_html__('Caption', 'infinite'),
                            'type' => 'textarea',
                            'condition' => array( 'enable-header-area' => 'enable', 'enable-page-title' => 'enable' )
                        ),                  
                        'title-background' => array(
                            'title' => esc_html__('Page Title Background', 'infinite'),
                            'type' => 'upload',
                            'condition' => array( 'enable-header-area' => 'enable', 'enable-page-title' => 'enable' )
                        ),
                        'enable-breadcrumbs' => array(
                            'title' => esc_html__('Enable Breadcrumbs', 'infinite'),
                            'type' => 'checkbox',
                            'default' => 'disable',
                            'condition' => array( 'enable-header-area' => 'enable', 'enable-page-title' => 'enable' )
                        ),
                        'body-background-type' => array(
                            'title' => esc_html__('Body Background Type', 'infinite'),
                            'type' => 'combobox',
                            'options' => array(
                                'default' => esc_html__('Default', 'infinite'),
                                'image' => esc_html__('Image ( Only For Boxed Layout )', 'infinite'),
                            )
                        ),
                        'body-background-image' => array(
                            'title' => esc_html__('Body Background Image', 'infinite'),
                            'type' => 'upload',
                            'data-type' => 'file', 
                            'condition' => array( 'body-background-type' => 'image' )
                        ),
                        'body-background-image-opacity' => array(
                            'title' => esc_html__('Body Background Image Opacity', 'infinite'),
                            'type' => 'fontslider',
                            'data-type' => 'opacity',
                            'default' => '100',
                            'condition' => array( 'body-background-type' => 'image' )
                        ),
                        'show-content' => array(
                            'title' => esc_html__('Show WordPress Editor Content', 'infinite'),
                            'type' => 'checkbox',
                            'default' => 'enable',
                            'description' => esc_html__('Disable this to hide the content in editor to show only page builder content.', 'infinite'),
                        ),
                        'sidebar' => array(
                            'title' => esc_html__('Sidebar', 'infinite'),
                            'type' => 'radioimage',
                            'options' => 'sidebar',
                            'default' => 'none',
                            'wrapper-class' => 'gdlr-core-fullsize'
                        ),
                        'sidebar-left' => array(
                            'title' => esc_html__('Sidebar Left', 'infinite'),
                            'type' => 'combobox',
                            'options' => 'sidebar',
                            'condition' => array( 'sidebar' => array('left', 'both') )
                        ),
                        'sidebar-right' => array(
                            'title' => esc_html__('Sidebar Right', 'infinite'),
                            'type' => 'combobox',
                            'options' => 'sidebar',
                            'condition' => array( 'sidebar' => array('right', 'both') )
                        ),
                        'enable-footer' => array(
                            'title' => esc_html__('Enable Footer', 'infinite'),
                            'type' => 'combobox',
                            'options' => array(
                                'default' => esc_html__('Default', 'infinite'),
                                'enable' => esc_html__('Enable', 'infinite'),
                                'disable' => esc_html__('Disable', 'infinite'),
                            )
                        ),
                        'enable-copyright' => array(
                            'title' => esc_html__('Enable Copyright', 'infinite'),
                            'type' => 'combobox',
                            'options' => array(
                                'default' => esc_html__('Default', 'infinite'),
                                'enable' => esc_html__('Enable', 'infinite'),
                                'disable' => esc_html__('Disable', 'infinite'),
                            )
                        ),

                    )
                ), // layout
                'title' => array(
                    'title' => esc_html__('Title Style', 'infinite'),
                    'options' => array(

                        'title-style' => array(
                            'title' => esc_html__('Page Title Style', 'infinite'),
                            'type' => 'combobox',
                            'options' => array(
                                'default' => esc_html__('Default', 'infinite'),
                                'small' => esc_html__('Small', 'infinite'),
                                'medium' => esc_html__('Medium', 'infinite'),
                                'large' => esc_html__('Large', 'infinite'),
                                'custom' => esc_html__('Custom', 'infinite'),
                            ),
                            'default' => 'default'
                        ),
                        'title-align' => array(
                            'title' => esc_html__('Page Title Alignment', 'infinite'),
                            'type' => 'radioimage',
                            'options' => 'text-align',
                            'with-default' => true,
                            'default' => 'default'
                        ),
                        'title-spacing' => array(
                            'title' => esc_html__('Page Title Padding', 'infinite'),
                            'type' => 'custom',
                            'item-type' => 'padding',
                            'data-input-type' => 'pixel',
                            'options' => array('padding-top', 'padding-bottom', 'caption-top-margin'),
                            'wrapper-class' => 'gdlr-core-fullsize gdlr-core-no-link gdlr-core-large',
                            'condition' => array( 'title-style' => 'custom' )
                        ),
                        'title-font-size' => array(
                            'title' => esc_html__('Page Title Font Size', 'infinite'),
                            'type' => 'custom',
                            'item-type' => 'padding',
                            'data-input-type' => 'pixel',
                            'options' => array('title-size', 'title-letter-spacing', 'caption-size', 'caption-letter-spacing'),
                            'wrapper-class' => 'gdlr-core-fullsize gdlr-core-no-link gdlr-core-large',
                            'condition' => array( 'title-style' => 'custom' )
                        ),
                        'title-font-weight' => array(
                            'title' => esc_html__('Page Title Font Weight', 'infinite'),
                            'type' => 'custom',
                            'item-type' => 'padding',
                            'options' => array('title-weight', 'caption-weight'),
                            'wrapper-class' => 'gdlr-core-fullsize gdlr-core-no-link gdlr-core-large',
                            'condition' => array( 'title-style' => 'custom' )
                        ),
                        'title-font-transform' => array(
                            'title' => esc_html__('Page Title Font Transform', 'infinite'),
                            'type' => 'combobox',
                            'options' => array(
                                'none' => esc_html__('None', 'infinite'),
                                'uppercase' => esc_html__('Uppercase', 'infinite'),
                                'lowercase' => esc_html__('Lowercase', 'infinite'),
                                'capitalize' => esc_html__('Capitalize', 'infinite'),
                            ),
                            'default' => 'uppercase',
                            'condition' => array( 'title-style' => 'custom' )
                        ),
                        'top-bottom-gradient' => array(
                            'title' => esc_html__('Title Top/Bottom Gradient', 'infinite'),
                            'type' => 'combobox',
                            'options' => array(
                                'default' => esc_html__('Default', 'infinite'),
                                'both' => esc_html__('Both', 'infinite'),
                                'top' => esc_html__('Top', 'infinite'),
                                'bottom' => esc_html__('Bottom', 'infinite'),
                                'disable' => esc_html__('None', 'infinite'),
                            )
                        ),
                        'title-background-overlay-opacity' => array(
                            'title' => esc_html__('Page Title Background Overlay Opacity', 'infinite'),
                            'type' => 'text',
                            'description' => esc_html__('Fill the number between 0.01 - 1 ( Leave Blank For Default Value )', 'infinite'),
                            'condition' => array( 'title-style' => 'custom' )
                        ),
                        'title-color' => array(
                            'title' => esc_html__('Page Title Color', 'infinite'),
                            'type' => 'colorpicker',
                        ),
                        'caption-color' => array(
                            'title' => esc_html__('Page Caption Color', 'infinite'),
                            'type' => 'colorpicker',
                        ),
                        'title-background-overlay-color' => array(
                            'title' => esc_html__('Page Background Overlay Color', 'infinite'),
                            'type' => 'colorpicker',
                        ),

                    )
                ), // title
                'header' => array(
                    'title' => esc_html__('Header', 'infinite'),
                    'options' => array(

                        'main_menu' => array(
                            'title' => esc_html__('Primary Menu', 'infinite'),
                            'type' => 'combobox',
                            'options' => function_exists('gdlr_core_get_menu_list')? gdlr_core_get_menu_list(): array(),
                            'single' => 'gdlr-core-location-main_menu'
                        ),
                        'right_menu' => array(
                            'title' => esc_html__('Secondary Menu', 'infinite'),
                            'type' => 'combobox',
                            'options' => function_exists('gdlr_core_get_menu_list')? gdlr_core_get_menu_list(): array(),
                            'single' => 'gdlr-core-location-right_menu'
                        ),
                        'top_bar_menu' => array(
                            'title' => esc_html__('Top Bar Menu', 'infinite'),
                            'type' => 'combobox',
                            'options' => function_exists('gdlr_core_get_menu_list')? gdlr_core_get_menu_list(): array(),
                            'single' => 'gdlr-core-location-top_bar_menu'
                        ),
                        'mobile_menu' => array(
                            'title' => esc_html__('Mobile Menu', 'infinite'),
                            'type' => 'combobox',
                            'options' => function_exists('gdlr_core_get_menu_list')? gdlr_core_get_menu_list(): array(),
                            'single' => 'gdlr-core-location-mobile_menu'
                        ),
                        
                        'header-slider' => array(
                            'title' => esc_html__('Header Slider ( Above Navigation )', 'infinite'),
                            'type' => 'combobox',
                            'options' => array(
                                'none' => esc_html__('None', 'infinite'),
                                'layer-slider' => esc_html__('Layer Slider', 'infinite'),
                                'master-slider' => esc_html__('Master Slider', 'infinite'),
                                'revolution-slider' => esc_html__('Revolution Slider', 'infinite'),
                            ),
                            'description' => esc_html__('For header style plain / bar / boxed', 'infinite'),
                        ),
                        'layer-slider-id' => array(
                            'title' => esc_html__('Choose Layer Slider', 'infinite'),
                            'type' => 'combobox',
                            'options' => gdlr_core_get_layerslider_list(),
                            'condition' => array( 'header-slider' => 'layer-slider' )
                        ),
                        'master-slider-id' => array(
                            'title' => esc_html__('Choose Master Slider', 'infinite'),
                            'type' => 'combobox',
                            'options' => gdlr_core_get_masterslider_list(),
                            'condition' => array( 'header-slider' => 'master-slider' )
                        ),
                        'revolution-slider-id' => array(
                            'title' => esc_html__('Choose Revolution Slider', 'infinite'),
                            'type' => 'combobox',
                            'options' => gdlr_core_get_revolution_slider_list(),
                            'condition' => array( 'header-slider' => 'revolution-slider' )
                        ),

                    ) // header options
                ), // header
                'bullet-anchor' => array(
                    'title' => esc_html__('Bullet Anchor', 'infinite'),
                    'options' => array(
                        'bullet-anchor-description' => array(
                            'type' => 'description',
                            'description' => esc_html__('This feature is used for one page navigation. It will appear on the right side of page. You can put the id of element in \'Anchor Link\' field to let the bullet scroll the page to.', 'infinite')
                        ),
                        'bullet-anchor' => array(
                            'title' => esc_html__('Add Anchor', 'infinite'),
                            'type' => 'custom',
                            'item-type' => 'tabs',
                            'options' => array(
                                'title' => array(
                                    'title' => esc_html__('Anchor Link', 'infinite'),
                                    'type' => 'text',
                                ),
                                'anchor-color' => array(
                                    'title' => esc_html__('Anchor Color', 'infinite'),
                                    'type' => 'colorpicker',
                                ),
                                'anchor-hover-color' => array(
                                    'title' => esc_html__('Anchor Hover Color', 'infinite'),
                                    'type' => 'colorpicker',
                                )
                            ),
                            'wrapper-class' => 'gdlr-core-fullsize'
                        ),
                    )
                )
            )
        ));

    }

}