<?php
/**
 * Make Theme Page Builder integration
 * 
 * @package Page_Generator_Pro
 * @author  Tim Carr
 * @version 3.3.7
 */
class Page_Generator_Pro_Make_Theme extends Page_Generator_Pro_Integration {

    /**
     * Holds the base object.
     *
     * @since   3.3.7
     *
     * @var     object
     */
    public $base;

    /**
     * Constructor
     * 
     * @since   3.3.7
     *
     * @param   object  $base    Base Plugin Class
     */
    public function __construct( $base ) {

        // Store base class
        $this->base = $base;

        // Set Theme Name
        $this->theme_name = 'Make';

        // Set Meta Keys used by this Plugin
        $this->meta_keys = array(
            "/^_ttfmake_(.*)/i",
            '_ttfmake-use-builder',
        );

        add_action( 'init', array( $this, 'register_make_theme_page_builder_support' ) );

        // Remove Page Builder data from Group Settings if overwriting content is disabled, and an existing generated page already exists
        add_filter( 'page_generator_pro_generate_remove_content_from_settings_ignored_keys', array( $this, 'remove_post_meta_from_content_group' ), 10, 2 );

        // Remove Plugin data from Group Settings if Plugin isn't active on Generation
        add_filter( 'page_generator_pro_groups_get_settings_remove_orphaned_settings', array( $this, 'remove_orphaned_settings' ) );

    }

    /**
     * Calls add_post_type_support to register Content Groups as supporting Make Builder's
     * Page Builder.
     *
     * @since   2.1.5
     */
    public function register_make_theme_page_builder_support() {

        add_post_type_support( 'page-generator-pro', 'make-builder' );

    }

    /**
     * Removes orphaned Make Builder metadata in the Group Settings during Generation,
     * if Make Builder is not active
     * 
     * @since   3.3.7
     * 
     * @param   array   $settings   Group Settings
     * @return  array               Group Settings
     */
    public function remove_orphaned_settings( $settings ) {

        // Don't remove settings if the Theme is active
        if ( $this->is_theme_active() ) {
            return $settings;
        }

        // Remove Make Builder Meta Keys from the Group Settings during Generation
        return $this->remove_orphaned_settings_metadata( $settings, $this->meta_keys );

    }

}